**Example 1: 关联日志配置项到应用**



Input: 

```
tccli tsf AssociateBusinessLogConfig --cli-unfold-argument  \
    --GroupId group-naldrdxy \
    --ConfigIdList apm-busi-log-cfg-2vzjgwyp
```

Output: 
```
{
    "Response": {
        "RequestId": "6735108a-c65a-4b3a-8f2b-40ed2f0df618",
        "Result": true
    }
}
```

